@@ -1673,12 +1673,7 @@ create_decomposed_metadata_tables (TrackerDBInterface *iface,
 	gboolean          in_alter = in_update;
 	GError           *error = NULL;
 
-	g_return_if_fail (TRACKER_IS_CLASS (service));
-
 	service_name = tracker_class_get_name (service);
-
-	g_return_if_fail (service_name != NULL);
-
 	main_class = (strcmp (service_name, "rdfs:Resource") == 0);
 
 	if (g_str_has_prefix (service_name, "xsd:")) {
@@ -1899,6 +1894,9 @@ create_decomposed_transient_metadata_tables (TrackerDBInterface *iface)
 
 			TrackerClass *domain;
 			const gchar *service_name;
+			const char *field_name;
+
+			field_name = tracker_property_get_name (property);
 
 			domain = tracker_property_get_domain (property);
 			service_name = tracker_class_get_name (domain);
@@ -2011,7 +2009,7 @@ get_new_service_id (TrackerDBInterface *iface)
 {
 	TrackerDBCursor    *cursor;
 	TrackerDBStatement *stmt;
-	gint max_service_id = 0;
+	gint max_service_id;
 
 	/* Don't intermix this thing with tracker_data_update_get_new_service_id,
 	 * if you use this, know what you are doing! */
