@@ -74,11 +74,6 @@ typedef struct {
 	gboolean get_mime;
 } SparqlQueryData;
 
-typedef struct {
-	GMainLoop *main_loop;
-	GHashTable *values;
-} CacheQueryData;
-
 typedef struct {
 	GMainLoop *main_loop;
 	GString   *sparql;
@@ -127,15 +122,6 @@ struct TrackerMinerFSPrivate {
 	GFile          *current_parent;
 	gchar          *current_parent_urn;
 
-	/* URI mtime cache */
-	GHashTable     *mtime_cache;
-
-	/* File -> iri cache */
-	GHashTable     *iri_cache;
-
-	/* Files to check if no longer exist */
-	GHashTable     *check_removed;
-
 	/* Status */
 	guint           been_started : 1;
 	guint           been_crawled : 1;
@@ -533,15 +519,6 @@ tracker_miner_fs_init (TrackerMinerFS *object)
 	                  object);
 
 	priv->quark_ignore_file = g_quark_from_static_string ("tracker-ignore-file");
-
-	priv->iri_cache = g_hash_table_new_full (g_file_hash,
-	                                         (GEqualFunc) g_file_equal,
-	                                         (GDestroyNotify) g_object_unref,
-	                                         (GDestroyNotify) g_free);
-	priv->check_removed = g_hash_table_new_full (g_file_hash,
-	                                             (GEqualFunc) g_file_equal,
-	                                             (GDestroyNotify) g_object_unref,
-	                                             NULL);
 }
 
 static ProcessData *
@@ -666,18 +643,6 @@ fs_finalize (GObject *object)
 
 	g_hash_table_unref (priv->items_ignore_next_update);
 
-	if (priv->mtime_cache) {
-		g_hash_table_unref (priv->mtime_cache);
-	}
-
-	if (priv->iri_cache) {
-		g_hash_table_unref (priv->iri_cache);
-	}
-
-	if (priv->check_removed) {
-		g_hash_table_unref (priv->check_removed);
-	}
-
 	G_OBJECT_CLASS (tracker_miner_fs_parent_class)->finalize (object);
 }
 
@@ -753,7 +718,7 @@ miner_started (TrackerMiner *miner)
 
 	g_object_set (miner,
 	              "progress", 0.0,
-	              "status", "Initializing",
+	              "status", _("Initializing"),
 	              NULL);
 
 	crawl_directories_start (fs);
@@ -764,7 +729,7 @@ miner_stopped (TrackerMiner *miner)
 {
 	g_object_set (miner,
 	              "progress", 1.0,
-	              "status", "Idle",
+	              "status", _("Idle"),
 	              NULL);
 }
 
@@ -918,7 +883,7 @@ process_stop (TrackerMinerFS *fs)
 
 	g_object_set (fs,
 	              "progress", 1.0,
-	              "status", "Idle",
+	              "status", _("Idle"),
 	              NULL);
 
 	g_signal_emit (fs, signals[FINISHED], 0,
@@ -989,29 +954,6 @@ sparql_update_cb (GObject      *object,
 			 */
 			tracker_miner_commit (TRACKER_MINER (fs), NULL, commit_cb, NULL);
 		}
-
-		if (fs->private->current_parent) {
-			GFile *parent;
-
-			/* Note: parent may be NULL if the file represents
-			 * the root directory of the file system (applies to
-			 * .gvfs mounts also!) */
-			parent = g_file_get_parent (data->file);
-
-			if (parent) {
-				if (g_file_equal (parent, fs->private->current_parent) &&
-				    g_hash_table_lookup (fs->private->iri_cache, data->file) == NULL) {
-					/* Item is processed, add an empty element for the processed GFile,
-					 * in case it is again processed before the cache expires
-					 */
-					g_hash_table_insert (fs->private->iri_cache,
-					                     g_object_ref (data->file),
-					                     NULL);
-				}
-
-				g_object_unref (parent);
-			}
-		}
 	}
 
 	priv->processing_pool = g_list_remove (priv->processing_pool, data);
@@ -1109,162 +1051,6 @@ item_query_exists (TrackerMinerFS  *miner,
 	return result;
 }
 
-static void
-cache_query_cb (GObject	     *object,
-		GAsyncResult *result,
-		gpointer      user_data)
-{
-	const GPtrArray *query_results;
-	TrackerMiner *miner;
-	CacheQueryData *data;
-	GError *error = NULL;
-	guint i;
-
-	data = user_data;
-	miner = TRACKER_MINER (object);
-	query_results = tracker_miner_execute_sparql_finish (miner, result, &error);
-
-	g_main_loop_quit (data->main_loop);
-
-	if (G_UNLIKELY (error)) {
-		g_critical ("Could not execute cache query: %s", error->message);
-		g_error_free (error);
-		return;
-	}
-
-	for (i = 0; i < query_results->len; i++) {
-		GFile *file;
-		GStrv strv;
-
-		strv = g_ptr_array_index (query_results, i);
-		file = g_file_new_for_uri (strv[0]);
-
-		g_hash_table_insert (data->values, file, g_strdup (strv[1]));
-	}
-}
-
-static gboolean
-file_is_crawl_directory (TrackerMinerFS *fs,
-                         GFile          *file)
-{
-	GList *dirs;
-
-	/* Check whether file is a crawl directory itself */
-	dirs = fs->private->config_directories;
-
-	while (dirs) {
-		DirectoryData *data;
-
-		data = dirs->data;
-		dirs = dirs->next;
-
-		if (g_file_equal (data->file, file)) {
-			return TRUE;
-		}
-	}
-
-	return FALSE;
-}
-
-static void
-ensure_iri_cache (TrackerMinerFS *fs,
-                  GFile          *file)
-{
-	gchar *query, *uri;
-	CacheQueryData data;
-	GFile *parent;
-
-	g_hash_table_remove_all (fs->private->iri_cache);
-
-	/* Note: parent may be NULL if the file represents
-	 * the root directory of the file system (applies to
-	 * .gvfs mounts also!) */
-	parent = g_file_get_parent (file);
-
-	if (!parent) {
-		return;
-	}
-
-	uri = g_file_get_uri (parent);
-
-	g_debug ("Generating children cache for URI '%s'", uri);
-
-	query = g_strdup_printf ("SELECT ?url ?u { "
-	                         "  ?u nfo:belongsToContainer ?p ; "
-	                         "     nie:url ?url . "
-	                         "  ?p nie:url \"%s\" "
-	                         "}",
-	                         uri);
-	g_free (uri);
-
-	data.main_loop = g_main_loop_new (NULL, FALSE);
-	data.values = g_hash_table_ref (fs->private->iri_cache);
-
-	tracker_miner_execute_sparql (TRACKER_MINER (fs),
-	                              query,
-	                              NULL,
-	                              cache_query_cb,
-	                              &data);
-
-	g_main_loop_run (data.main_loop);
-
-	g_main_loop_unref (data.main_loop);
-	g_hash_table_unref (data.values);
-
-	if (g_hash_table_size (data.values) == 0 &&
-	    file_is_crawl_directory (fs, file)) {
-		gchar *query_iri;
-
-		if (item_query_exists (fs, file, &query_iri, NULL)) {
-			g_hash_table_insert (data.values,
-			                     g_object_ref (file), query_iri);
-		}
-	}
-
-	g_object_unref (parent);
-	g_free (query);
-}
-
-static const gchar *
-iri_cache_lookup (TrackerMinerFS *fs,
-                  GFile          *file)
-{
-	gpointer value;
-	const gchar *iri;
-
-	if (!g_hash_table_lookup_extended (fs->private->iri_cache, file, NULL, &value)) {
-		/* Item doesn't exist in cache */
-		return NULL;
-	}
-
-	iri = value;
-
-	if (!iri) {
-		gchar *query_iri;
-
-		/* Cache miss, this item was added after the last
-		 * iri cache update, so query it independently
-		 */
-		if (item_query_exists (fs, file, &query_iri, NULL)) {
-			g_hash_table_insert (fs->private->iri_cache,
-			                     g_object_ref (file), query_iri);
-			iri = query_iri;
-		} else {
-			g_hash_table_remove (fs->private->iri_cache, file);
-			iri = NULL;
-		}
-	}
-
-	return iri;
-}
-
-static void
-iri_cache_invalidate (TrackerMinerFS *fs,
-                      GFile          *file)
-{
-	g_hash_table_remove (fs->private->iri_cache, file);
-}
-
 static gboolean
 do_process_file (TrackerMinerFS *fs,
 		 ProcessData    *data)
@@ -1378,7 +1164,7 @@ item_add_or_update (TrackerMinerFS *fs,
 	gboolean retval;
 	ProcessData *data;
 	GFile *parent;
-	const gchar *urn;
+	gchar *urn;
 	const gchar *parent_urn = NULL;
 
 	priv = fs->private;
@@ -1388,6 +1174,8 @@ item_add_or_update (TrackerMinerFS *fs,
 	sparql = tracker_sparql_builder_new_update ();
 	g_object_ref (file);
 
+	item_query_exists (fs, file, &urn, NULL);
+
 	parent = g_file_get_parent (file);
 
 	if (parent) {
@@ -1404,21 +1192,18 @@ item_add_or_update (TrackerMinerFS *fs,
 
 			g_free (fs->private->current_parent_urn);
 
-			fs->private->current_parent = g_object_ref (parent);
-
-			if (!item_query_exists (fs, parent, &fs->private->current_parent_urn, NULL)) {
+			if (item_query_exists (fs, parent, &fs->private->current_parent_urn, NULL))
+				fs->private->current_parent = g_object_ref (parent);
+			else {
+				fs->private->current_parent = NULL;
 				fs->private->current_parent_urn = NULL;
 			}
-
-			ensure_iri_cache (fs, file);
 		}
 
 		parent_urn = fs->private->current_parent_urn;
 		g_object_unref (parent);
 	}
 
-	urn = iri_cache_lookup (fs, file);
-
 	data = process_data_new (file, urn, parent_urn, cancellable, sparql);
 	priv->processing_pool = g_list_prepend (priv->processing_pool, data);
 
@@ -1437,6 +1222,7 @@ item_add_or_update (TrackerMinerFS *fs,
 	g_object_unref (file);
 	g_object_unref (cancellable);
 	g_object_unref (sparql);
+	g_free (urn);
 
 	return retval;
 }
@@ -1446,18 +1232,17 @@ item_remove (TrackerMinerFS *fs,
              GFile          *file)
 {
 	GString *sparql;
-	gchar *uri;
+	gchar *uri, *slash_uri;
 	gchar *mime = NULL;
 	ProcessData *data;
 
-	iri_cache_invalidate (fs, file);
 	uri = g_file_get_uri (file);
 
 	g_debug ("Removing item: '%s' (Deleted from filesystem)",
 	         uri);
 
 	if (!item_query_exists (fs, file, NULL, &mime)) {
-		g_debug ("  File does not exist anyway (uri '%s')", uri);
+		g_debug ("  File does not exist anyway (uri:'%s')", uri);
 		g_free (uri);
 		g_free (mime);
 		return TRUE;
@@ -1467,6 +1252,12 @@ item_remove (TrackerMinerFS *fs,
 
 	g_free (mime);
 
+	if (!g_str_has_suffix (uri, "/")) {
+		slash_uri = g_strconcat (uri, "/", NULL);
+	} else {
+		slash_uri = g_strdup (uri);
+	}
+
 	sparql = g_string_new ("");
 
 	/* Delete all children */
@@ -1475,9 +1266,9 @@ item_remove (TrackerMinerFS *fs,
 	                        "  ?child a rdfs:Resource "
 	                        "} WHERE {"
 	                        "  ?child nie:url ?u . "
-	                        "  FILTER (tracker:uri-is-descendant (\"%s\", ?u)) "
+	                        "  FILTER (fn:starts-with (?u, \"%s\")) "
 	                        "}",
-	                        uri);
+	                        slash_uri);
 
 	/* Delete resource itself */
 	g_string_append_printf (sparql,
@@ -1498,6 +1289,7 @@ item_remove (TrackerMinerFS *fs,
 	                                    data);
 
 	g_string_free (sparql, TRUE);
+	g_free (slash_uri);
 	g_free (uri);
 
 	return FALSE;
@@ -1656,13 +1448,15 @@ item_update_children_uri (TrackerMinerFS    *fs,
                           const gchar       *source_uri,
                           const gchar       *uri)
 {
-	gchar *sparql;
+	gchar *slash_uri, *sparql;
+
+	slash_uri = g_strconcat (source_uri, "/", NULL);
 
 	sparql = g_strdup_printf ("SELECT ?child ?url nie:mimeType(?child) WHERE { "
 				  "  ?child nie:url ?url . "
-                                  "  FILTER (tracker:uri-is-descendant (\"%s\", ?url)) "
+				  "  FILTER (fn:starts-with (?url, \"%s\")) "
 				  "}",
-				  source_uri);
+				  slash_uri);
 
 	tracker_miner_execute_sparql (TRACKER_MINER (fs),
 	                              sparql,
@@ -1670,6 +1464,7 @@ item_update_children_uri (TrackerMinerFS    *fs,
 	                              item_update_children_uri_cb,
 	                              move_data);
 
+	g_free (slash_uri);
 	g_free (sparql);
 }
 
@@ -1678,18 +1473,14 @@ item_move (TrackerMinerFS *fs,
            GFile          *file,
            GFile          *source_file)
 {
-	gchar     *uri, *source_uri;
+	gchar     *uri, *source_uri, *escaped_filename;
 	GFileInfo *file_info;
 	GString   *sparql;
 	RecursiveMoveData move_data;
 	ProcessData *data;
 	gchar *source_iri;
-	gchar *display_name;
 	gboolean source_exists;
 
-	iri_cache_invalidate (fs, file);
-	iri_cache_invalidate (fs, source_file);
-
 	uri = g_file_get_uri (file);
 	source_uri = g_file_get_uri (source_file);
 
@@ -1746,7 +1537,7 @@ item_move (TrackerMinerFS *fs,
 	         source_uri,
 	         uri);
 
-	tracker_thumbnailer_move_add (source_uri,
+	tracker_thumbnailer_move_add (source_uri, 
 	                              g_file_info_get_content_type (file_info),
 	                              uri);
 
@@ -1773,7 +1564,7 @@ item_move (TrackerMinerFS *fs,
 	                        "} ",
 	                        source_iri, source_iri, source_iri);
 
-	display_name = tracker_sparql_escape (g_file_info_get_display_name (file_info));
+	escaped_filename = g_strescape (g_file_info_get_display_name (file_info), NULL);
 
 	g_string_append_printf (sparql,
 	                        "INSERT INTO <%s> {"
@@ -1782,10 +1573,10 @@ item_move (TrackerMinerFS *fs,
 	                        "       nie:isStoredAs <%s> "
 	                        "} ",
 	                        source_iri, source_iri,
-	                        display_name, uri,
+	                        escaped_filename, uri,
 	                        source_iri);
 
-	g_free (display_name);
+	g_free (escaped_filename);
 
 	move_data.main_loop = g_main_loop_new (NULL, FALSE);
 	move_data.sparql = sparql;
@@ -2206,10 +1997,10 @@ item_queue_handlers_set_up (TrackerMinerFS *fs)
 
 	g_object_get (fs, "status", &status, NULL);
 
-	if (g_strcmp0 (status, "Processing…") != 0) {
+	if (g_strcmp0 (status, _("Processing files")) != 0) {
 		/* Don't spam this */
-		g_message ("Processing…");
-		g_object_set (fs, "status", "Processing…", NULL);
+		g_message ("Processing files...");
+		g_object_set (fs, "status", _("Processing files"), NULL);
 	}
 
 	g_free (status);
@@ -2220,177 +2011,17 @@ item_queue_handlers_set_up (TrackerMinerFS *fs)
 		                   fs);
 }
 
-static gboolean
-remove_unexisting_file_cb (gpointer key,
-                           gpointer value,
-                           gpointer user_data)
-{
-	TrackerMinerFS *fs = user_data;
-	GFile *file = key;
-
-	/* If file no longer exists, remove it from the store*/
-	if (!g_file_query_exists (file, NULL)) {
-		gchar *uri;
-
-		uri = g_file_get_uri (file);
-		g_debug ("  Marking file which no longer exists in FS for removal: %s", uri);
-		g_free (uri);
-
-		g_queue_push_tail (fs->private->items_deleted,
-		                   g_object_ref (file));
-
-		item_queue_handlers_set_up (fs);
-	}
-
-	return TRUE;
-}
-
-static void
-check_if_files_removed (TrackerMinerFS *fs)
-{
-	g_debug ("Checking if any file was removed...");
-	g_hash_table_foreach_remove (fs->private->check_removed,
-	                             remove_unexisting_file_cb,
-	                             fs);
-}
-
-static void
-add_to_check_removed_cb (gpointer key,
-                         gpointer value,
-                         gpointer user_data)
-{
-	TrackerMinerFS *fs = user_data;
-	GFile *file = key;
-
-	/* Not adding any data to the value, we just want
-	 * fast search for key availability */
-	g_hash_table_insert (fs->private->check_removed,
-	                     g_object_ref (file),
-	                     NULL);
-}
-
-static void
-ensure_mtime_cache (TrackerMinerFS *fs,
-                    GFile          *file)
-{
-	gchar *query, *uri;
-	CacheQueryData data;
-	GFile *parent;
-
-	if (G_UNLIKELY (!fs->private->mtime_cache)) {
-		fs->private->mtime_cache = g_hash_table_new_full (g_file_hash,
-		                                                  (GEqualFunc) g_file_equal,
-		                                                  (GDestroyNotify) g_object_unref,
-		                                                  (GDestroyNotify) g_free);
-	}
-
-	/* Note: parent may be NULL if the file represents
-	 * the root directory of the file system (applies to
-	 * .gvfs mounts also!) */
-	parent = g_file_get_parent (file);
-
-	if (fs->private->current_parent) {
-		if (parent &&
-		    g_file_equal (parent, fs->private->current_parent)) {
-			/* Cache is still valid */
-			g_object_unref (parent);
-			return;
-		}
-
-		g_object_unref (fs->private->current_parent);
-	}
-
-	fs->private->current_parent = parent;
-
-	g_hash_table_remove_all (fs->private->mtime_cache);
-
-	/* Initialize data contents */
-	data.main_loop = g_main_loop_new (NULL, FALSE);
-	data.values = g_hash_table_ref (fs->private->mtime_cache);
-
-	if (parent) {
-		uri = g_file_get_uri (parent);
-
-		g_debug ("Generating mtime cache for URI '%s'", uri);
-
-		query = g_strdup_printf ("SELECT ?url ?last { ?u nfo:belongsToContainer ?p ; "
-		                                                "nie:url ?url ; "
-		                                                "nfo:fileLastModified ?last . "
-		                                             "?p nie:url \"%s\" }", uri);
-
-		g_free (uri);
-
-		tracker_miner_execute_sparql (TRACKER_MINER (fs),
-		                              query,
-		                              NULL,
-		                              cache_query_cb,
-		                              &data);
-		g_free (query);
-
-		g_main_loop_run (data.main_loop);
-	}
-
-	if ((!parent || g_hash_table_size (data.values) == 0) &&
-	    file_is_crawl_directory (fs, file)) {
-		/* File is a crawl directory itself, query its mtime directly */
-		uri = g_file_get_uri (file);
-
-		g_debug ("Generating mtime cache for URI '%s' (config location)", uri);
-
-		query = g_strdup_printf ("SELECT ?url ?last "
-		                         "WHERE { "
-		                         "  ?u nfo:fileLastModified ?last ; "
-		                         "     nie:url ?url ; "
-		                         "     nie:url \"%s\" "
-		                         "}",
-					 uri);
-		g_free (uri);
-
-		tracker_miner_execute_sparql (TRACKER_MINER (fs),
-		                              query,
-		                              NULL,
-		                              cache_query_cb,
-		                              &data);
-		g_free (query);
-
-		g_main_loop_run (data.main_loop);
-	}
-
-	g_main_loop_unref (data.main_loop);
-	g_hash_table_unref (data.values);
-
-	/* Iterate repopulated HT and add all to the check_removed HT */
-	g_hash_table_foreach (fs->private->mtime_cache,
-	                      add_to_check_removed_cb,
-	                      fs);
-}
-
 static gboolean
 should_change_index_for_file (TrackerMinerFS *fs,
                               GFile          *file)
 {
+	gboolean            uptodate;
 	GFileInfo          *file_info;
 	guint64             time;
 	time_t              mtime;
 	struct tm           t;
-	gchar              *time_str, *lookup_time;
-
-	/* Make sure mtime cache contains the mtimes of all files in the
-	 * same directory as the given file
-	 */
-	ensure_mtime_cache (fs, file);
-
-	/* Remove the file from the list of files to be checked if removed */
-	g_hash_table_remove (fs->private->check_removed, file);
-
-	/* If the file is NOT found in the cache, it means its a new
-	 * file the store doesn't know about, so just report it to be
-	 * re-indexed.
-	 */
-	lookup_time = g_hash_table_lookup (fs->private->mtime_cache, file);
-	if (!lookup_time) {
-		return TRUE;
-	}
+	gchar              *query, *uri;
+	SparqlQueryData     data = { 0 };
 
 	file_info = g_file_query_info (file,
 	                               G_FILE_ATTRIBUTE_TIME_MODIFIED,
@@ -2408,17 +2039,42 @@ should_change_index_for_file (TrackerMinerFS *fs,
 	mtime = (time_t) time;
 	g_object_unref (file_info);
 
+	uri = g_file_get_uri (file);
+
 	gmtime_r (&mtime, &t);
 
-	time_str = g_strdup_printf ("%04d-%02d-%02dT%02d:%02d:%02dZ",
-	                            t.tm_year + 1900,
-	                            t.tm_mon + 1,
-	                            t.tm_mday,
-	                            t.tm_hour,
-	                            t.tm_min,
-	                            t.tm_sec);
+	query = g_strdup_printf ("SELECT ?file { "
+	                         "  ?file nfo:fileLastModified \"%04d-%02d-%02dT%02d:%02d:%02dZ\" . "
+	                         "  ?file nie:url \"%s\""
+	                         "}",
+	                         t.tm_year + 1900,
+	                         t.tm_mon + 1,
+	                         t.tm_mday,
+	                         t.tm_hour,
+	                         t.tm_min,
+	                         t.tm_sec,
+	                         uri);
 
-	if (strcmp (time_str, lookup_time) == 0) {
+	data.get_mime = FALSE;
+	data.main_loop = g_main_loop_new (NULL, FALSE);
+	data.uri = uri;
+
+	tracker_miner_execute_sparql (TRACKER_MINER (fs),
+	                              query,
+	                              NULL,
+	                              sparql_query_cb,
+	                              &data);
+
+	g_main_loop_run (data.main_loop);
+	uptodate = (data.iri != NULL);
+
+	g_main_loop_unref (data.main_loop);
+	g_free (data.iri);
+	g_free (data.mime);
+	g_free (query);
+	g_free (uri);
+
+	if (uptodate) {
 		/* File already up-to-date in the database */
 		return FALSE;
 	}
@@ -2860,9 +2516,6 @@ crawler_finished_cb (TrackerCrawler *crawler,
 	directory_data_unref (fs->private->current_directory);
 	fs->private->current_directory = NULL;
 
-	/* Check if any file was left after whole crawling */
-	check_if_files_removed (fs);
-
 	/* Proceed to next thing to process */
 	crawl_directories_start (fs);
 }
@@ -2871,7 +2524,7 @@ static gboolean
 crawl_directories_cb (gpointer user_data)
 {
 	TrackerMinerFS *fs = user_data;
-	gchar *path, *path_utf8;
+	gchar *path;
 	gchar *str;
 
 	if (fs->private->current_directory) {
@@ -2881,12 +2534,6 @@ crawl_directories_cb (gpointer user_data)
 	}
 
 	if (!fs->private->directories) {
-		if (fs->private->current_parent) {
-			/* Unset parent folder so caches are regenerated */
-			g_object_unref (fs->private->current_parent);
-			fs->private->current_parent = NULL;
-		}
-
 		/* Now we handle the queue */
 		item_queue_handlers_set_up (fs);
 		crawl_directories_stop (fs);
@@ -2904,15 +2551,12 @@ crawl_directories_cb (gpointer user_data)
 	                                          fs->private->current_directory);
 
 	path = g_file_get_path (fs->private->current_directory->file);
-	path_utf8 = g_filename_to_utf8 (path, -1, NULL, NULL, NULL);
-	g_free (path);
 
 	if (fs->private->current_directory->recurse) {
-		str = g_strdup_printf ("Crawling recursively directory '%s'", path_utf8);
+		str = g_strdup_printf (_("Crawling recursively directory '%s'"), path);
 	} else {
-		str = g_strdup_printf ("Crawling single directory '%s'", path_utf8);
+		str = g_strdup_printf (_("Crawling single directory '%s'"), path);
 	}
-	g_free (path_utf8);
 
 	g_message ("%s", str);
 
@@ -2922,6 +2566,7 @@ crawl_directories_cb (gpointer user_data)
 	              "status", str,
 	              NULL);
 	g_free (str);
+	g_free (path);
 
 	if (tracker_crawler_start (fs->private->crawler,
 	                           fs->private->current_directory->file,
@@ -3011,23 +2656,6 @@ should_recurse_for_directory (TrackerMinerFS *fs,
 	return recurse;
 }
 
-
-/* Returns 0 if 'a' and 'b' point to the same diretory, OR if
- *  'b' is contained inside directory 'a' and 'a' is recursively
- *  indexed. */
-static gint
-directory_compare_cb (gconstpointer a,
-                      gconstpointer b)
-{
-	DirectoryData *dda = (DirectoryData *) a;
-	DirectoryData *ddb = (DirectoryData *) b;
-
-	return (g_file_equal (dda->file, ddb->file) ||
-	        (dda->recurse &&
-	         g_file_has_prefix (ddb->file, dda->file))) ? 0 : -1;
-}
-
-
 /* This function is for internal use, adds the file to the processing
  * queue with the same directory settings than the corresponding
  * config directory.
@@ -3042,18 +2670,10 @@ tracker_miner_fs_directory_add_internal (TrackerMinerFS *fs,
 	recurse = should_recurse_for_directory (fs, file);
 	data = directory_data_new (file, recurse);
 
-	/* Only add if not already there */
-	if (!g_list_find_custom (fs->private->directories,
-	                         data,
-	                         directory_compare_cb)) {
-		fs->private->directories =
-			g_list_append (fs->private->directories,
-			               directory_data_ref (data));
+	fs->private->directories =
+		g_list_append (fs->private->directories, data);
 
-		crawl_directories_start (fs);
-	}
-
-	directory_data_unref (data);
+	crawl_directories_start (fs);
 }
 
 /**
@@ -3076,27 +2696,14 @@ tracker_miner_fs_directory_add (TrackerMinerFS *fs,
 
 	dir_data = directory_data_new (file, recurse);
 
-	/* New directory to add in config_directories? */
-	if (!g_list_find_custom (fs->private->config_directories,
-	                         dir_data,
-	                         directory_compare_cb)) {
-		fs->private->config_directories =
-			g_list_append (fs->private->config_directories,
-			               directory_data_ref (dir_data));
-	}
+	fs->private->config_directories =
+		g_list_append (fs->private->config_directories, dir_data);
 
-	/* If not already in the list to process, add it */
-	if (!g_list_find_custom (fs->private->directories,
-	                         dir_data,
-	                         directory_compare_cb)) {
-		fs->private->directories =
-			g_list_append (fs->private->directories,
-			               directory_data_ref (dir_data));
+	fs->private->directories =
+		g_list_append (fs->private->directories,
+			       directory_data_ref (dir_data));
 
-		crawl_directories_start (fs);
-	}
-
-	directory_data_unref (dir_data);
+	crawl_directories_start (fs);
 }
 
 static void
@@ -3207,9 +2814,6 @@ tracker_miner_fs_directory_remove (TrackerMinerFS *fs,
 		pool = pool->next;
 	}
 
-	/* Remove all monitors */
-	tracker_monitor_remove_recursively (fs->private->monitor, file);
-
 	return return_val;
 }
 
