@@ -90,6 +90,7 @@ enum {
 	PAUSED,
 	RESUMED,
 	PROGRESS,
+	ERROR,
 	IGNORE_NEXT_UPDATE,
 	LAST_SIGNAL
 };
@@ -220,6 +221,23 @@ tracker_miner_class_init (TrackerMinerClass *klass)
 		              G_TYPE_NONE, 2,
 		              G_TYPE_STRING,
 		              G_TYPE_DOUBLE);
+	/**
+	 * TrackerMiner::error:
+	 * @miner: the #TrackerMiner
+	 * @error: the error that happened
+	 *
+	 * The ::error signal will be emitted by TrackerMiner implementations to
+	 * indicate some error in the data mining process.
+	 **/
+	signals[ERROR] =
+		g_signal_new ("error",
+		              G_OBJECT_CLASS_TYPE (object_class),
+		              G_SIGNAL_RUN_LAST,
+		              G_STRUCT_OFFSET (TrackerMinerClass, error),
+		              NULL, NULL,
+		              g_cclosure_marshal_VOID__POINTER,
+		              G_TYPE_NONE, 1,
+		              G_TYPE_POINTER);
 
 	/**
 	 * TrackerMiner::ignore-next-update:
@@ -422,8 +440,7 @@ store_name_monitor_cb (TrackerMiner *miner,
 {
 	GError *error = NULL;
 
-	g_debug ("Store availability has changed to %s",
-		 available ? "AVAILABLE" : "UNAVAILABLE");
+	g_debug ("Tracker-store availability has changed to %d", available);
 
 	if (available && miner->private->availability_cookie != 0) {
 		tracker_miner_resume (miner,
@@ -431,7 +448,7 @@ store_name_monitor_cb (TrackerMiner *miner,
 		                      &error);
 
 		if (error) {
-			g_warning ("Error happened resuming miner, %s", error->message);
+			g_warning ("Error happened resuming miner: %s\n", error->message);
 			g_error_free (error);
 		}
 
@@ -444,7 +461,7 @@ store_name_monitor_cb (TrackerMiner *miner,
 		                                 &error);
 
 		if (error) {
-			g_warning ("Could not pause, %s", error->message);
+			g_warning ("Could not pause: %s", error->message);
 			g_error_free (error);
 		} else {
 			miner->private->availability_cookie = cookie_id;
@@ -654,7 +671,12 @@ static void
 sparql_cancelled_cb (GCancellable  *cancellable,
                      AsyncCallData *data)
 {
+	TrackerMinerPrivate *priv;
+
 	async_call_data_notify_error (data, 0, "SPARQL operation was cancelled");
+
+	priv = TRACKER_MINER_GET_PRIVATE (data->miner);
+
 	async_call_data_destroy (data, TRUE);
 }
 
@@ -762,12 +784,14 @@ tracker_miner_execute_update (TrackerMiner        *miner,
                               GAsyncReadyCallback  callback,
                               gpointer             user_data)
 {
+	TrackerMinerPrivate *priv;
 	AsyncCallData *data;
 
 	g_return_if_fail (TRACKER_IS_MINER (miner));
 	g_return_if_fail (sparql != NULL);
 	g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
 
+	priv = TRACKER_MINER_GET_PRIVATE (miner);
 	data = async_call_data_new (miner,
 	                            cancellable,
 	                            callback,
@@ -826,6 +850,7 @@ tracker_miner_execute_sparql (TrackerMiner        *miner,
                               GAsyncReadyCallback  callback,
                               gpointer             user_data)
 {
+	TrackerMinerPrivate *priv;
 	AsyncCallData *data;
 
 	g_return_if_fail (TRACKER_IS_MINER (miner));
@@ -833,6 +858,7 @@ tracker_miner_execute_sparql (TrackerMiner        *miner,
 	g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
 	g_return_if_fail (callback != NULL);
 
+	priv = TRACKER_MINER_GET_PRIVATE (miner);
 	data = async_call_data_new (miner, cancellable, callback, user_data, tracker_miner_execute_sparql);
 
 	data->id = tracker_resources_sparql_query_async (miner->private->client,
@@ -891,12 +917,14 @@ tracker_miner_execute_batch_update (TrackerMiner        *miner,
                                     GAsyncReadyCallback  callback,
                                     gpointer             user_data)
 {
+	TrackerMinerPrivate *priv;
 	AsyncCallData *data;
 
 	g_return_if_fail (TRACKER_IS_MINER (miner));
 	g_return_if_fail (sparql != NULL);
 	g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
 
+	priv = TRACKER_MINER_GET_PRIVATE (miner);
 	data = async_call_data_new (miner, cancellable, callback, user_data, tracker_miner_execute_batch_update);
 
 	data->id = tracker_resources_batch_sparql_update_async (miner->private->client,
@@ -948,11 +976,13 @@ tracker_miner_commit (TrackerMiner        *miner,
                       gpointer             user_data)
 
 {
+	TrackerMinerPrivate *priv;
 	AsyncCallData *data;
 
 	g_return_if_fail (TRACKER_IS_MINER (miner));
 	g_return_if_fail (!cancellable || G_IS_CANCELLABLE (cancellable));
 
+	priv = TRACKER_MINER_GET_PRIVATE (miner);
 	data = async_call_data_new (miner, cancellable, callback, user_data, tracker_miner_commit);
 
 	data->id = tracker_resources_batch_commit_async (miner->private->client,
@@ -1115,8 +1145,9 @@ _tracker_miner_dbus_get_progress (TrackerMiner           *miner,
 
 	tracker_dbus_request_new (request_id, context, "%s()", __PRETTY_FUNCTION__);
 
-	tracker_dbus_request_success (request_id, context);
 	dbus_g_method_return (context, miner->private->progress);
+
+	tracker_dbus_request_success (request_id, context);
 }
 
 void
