@@ -36,8 +36,6 @@
 #include <libtracker-common/tracker-type-utils.h>
 #include <libtracker-common/tracker-utils.h>
 
-#include <libtracker-db/tracker-db.h>
-
 #include "tracker-miner-files.h"
 #include "tracker-config.h"
 #include "tracker-extract-client.h"
@@ -45,9 +43,6 @@
 
 #define DISK_SPACE_CHECK_FREQUENCY 10
 
-/* Default DBus timeout to be used in requests to extractor (milliseconds) */
-#define EXTRACTOR_DBUS_TIMEOUT 60000
-
 #define TRACKER_MINER_FILES_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TRACKER_TYPE_MINER_FILES, TrackerMinerFilesPrivate))
 
 static GQuark miner_files_error_quark = 0;
@@ -65,22 +60,18 @@ struct ProcessFileData {
 struct TrackerMinerFilesPrivate {
 	TrackerConfig *config;
 	TrackerStorage *storage;
+	TrackerPower *power;
 
 	GVolumeMonitor *volume_monitor;
 
-	GSList *index_recursive_directories;
-	GSList *index_single_directories;
+        GSList *index_recursive_directories;
+        GSList *index_single_directories;
 
 	guint disk_space_check_id;
 	guint disk_space_pause_cookie;
 
 	guint low_battery_pause_cookie;
 
-#if defined(HAVE_DEVKIT_POWER) || defined(HAVE_HAL)
-	TrackerPower *power;
-#endif /* defined(HAVE_DEVKIT_POWER) || defined(HAVE_HAL) */
-	gulong finished_handler;
-
 	DBusGProxy *extractor_proxy;
 
 	GQuark quark_mount_point_uuid;
@@ -127,9 +118,7 @@ static void        check_battery_status                 (TrackerMinerFiles    *f
 static void        battery_status_cb                    (GObject              *object,
                                                          GParamSpec           *pspec,
                                                          gpointer              user_data);
-static void        index_on_battery_cb                  (GObject    *object,
-                                                         GParamSpec *pspec,
-                                                         gpointer    user_data);
+
 static void        init_mount_points                    (TrackerMinerFiles    *miner);
 static void        disk_space_check_start               (TrackerMinerFiles    *mf);
 static void        disk_space_check_stop                (TrackerMinerFiles    *mf);
@@ -142,10 +131,9 @@ static void        index_recursive_directories_cb       (GObject              *g
 static void        index_single_directories_cb          (GObject              *gobject,
                                                          GParamSpec           *arg1,
                                                          gpointer              user_data);
-static gboolean    miner_files_force_recheck_idle       (gpointer user_data);
-static void        trigger_recheck_cb                   (GObject              *gobject,
-                                                         GParamSpec           *arg1,
-                                                         gpointer              user_data);
+static void        ignore_directories_cb                (GObject              *gobject,
+							 GParamSpec           *arg1,
+							 gpointer              user_data);
 static DBusGProxy *extractor_create_proxy               (void);
 static gboolean    miner_files_check_file               (TrackerMinerFS       *fs,
                                                          GFile                *file);
@@ -167,13 +155,6 @@ static gboolean    miner_files_ignore_next_update_file  (TrackerMinerFS       *f
 static void      extractor_get_embedded_metadata_cancel (GCancellable    *cancellable,
                                                          ProcessFileData *data);
 
-static void        miner_finished_cb                    (TrackerMinerFS *fs,
-                                                         gdouble         seconds_elapsed,
-                                                         guint           total_directories_found,
-                                                         guint           total_directories_ignored,
-                                                         guint           total_files_found,
-                                                         guint           total_files_ignored,
-                                                         gpointer        user_data);
 
 G_DEFINE_TYPE (TrackerMinerFiles, tracker_miner_files, TRACKER_TYPE_MINER_FS)
 
@@ -236,10 +217,6 @@ tracker_miner_files_init (TrackerMinerFiles *mf)
 	                  mf);
 #endif /* defined(HAVE_DEVKIT_POWER) || defined(HAVE_HAL) */
 
-	priv->finished_handler = g_signal_connect_after (mf, "finished",
-							 G_CALLBACK (miner_finished_cb),
-							 NULL);
-
 	priv->volume_monitor = g_volume_monitor_get ();
 	g_signal_connect (priv->volume_monitor, "mount-pre-unmount",
 	                  G_CALLBACK (mount_pre_unmount_cb),
@@ -506,7 +483,7 @@ miner_files_constructed (GObject *object)
 		g_object_unref (file);
 	}
 
-	/* We want to get notified when config changes */
+	/* Add optical media */
 
 	g_signal_connect (mf->private->config, "notify::low-disk-space-limit",
 	                  G_CALLBACK (low_disk_space_limit_cb),
@@ -518,25 +495,11 @@ miner_files_constructed (GObject *object)
 	                  G_CALLBACK (index_single_directories_cb),
 	                  mf);
 	g_signal_connect (mf->private->config, "notify::ignored-directories",
-	                  G_CALLBACK (trigger_recheck_cb),
+	                  G_CALLBACK (ignore_directories_cb),
 	                  mf);
 	g_signal_connect (mf->private->config, "notify::ignored-directories-with-content",
-	                  G_CALLBACK (trigger_recheck_cb),
+	                  G_CALLBACK (ignore_directories_cb),
 	                  mf);
-	g_signal_connect (mf->private->config, "notify::ignored-files",
-	                  G_CALLBACK (trigger_recheck_cb),
-	                  mf);
-
-#if defined(HAVE_DEVKIT_POWER) || defined(HAVE_HAL)
-
-	g_signal_connect (mf->private->config, "notify::index-on-battery",
-	                  G_CALLBACK (index_on_battery_cb),
-	                  mf);
-	g_signal_connect (mf->private->config, "notify::index-on-battery-first-time",
-	                  G_CALLBACK (index_on_battery_cb),
-	                  mf);
-
-#endif /* defined(HAVE_DEVKIT_POWER) || defined(HAVE_HAL) */
 
 	g_slist_foreach (mounts, (GFunc) g_free, NULL);
 	g_slist_free (mounts);
@@ -550,16 +513,15 @@ set_up_mount_point_cb (GObject      *source,
                        gpointer      user_data)
 {
 	gchar *removable_device_urn = user_data;
-	GError *error = NULL;
 
+	GError *error = NULL;
 	tracker_miner_execute_update_finish (TRACKER_MINER (source),
 	                                     result,
 	                                     &error);
 
 	if (error) {
-		g_critical ("Could not set mount point in database '%s', %s",
-		            removable_device_urn,
-			    error->message);
+		g_critical ("Could not set up mount point '%s': %s",
+		            removable_device_urn, error->message);
 		g_error_free (error);
 	}
 
@@ -575,13 +537,13 @@ set_up_mount_point (TrackerMinerFiles *miner,
 {
 	GString *queries;
 
+	g_debug ("Setting mount point '%s' state in database (URN '%s')", 
+	         mount_point,
+	         removable_device_urn);
+
 	queries = g_string_new (NULL);
 
 	if (mounted) {
-		g_debug ("Mount point state (MOUNTED) being set in DB for URN '%s' (mount_point: %s)",
-		         removable_device_urn,
-		         mount_point ? mount_point : "unknown");
-
 		if (mount_point) {
 			GFile *file;
 			gchar *uri;
@@ -589,15 +551,6 @@ set_up_mount_point (TrackerMinerFiles *miner,
 			file = g_file_new_for_path (mount_point);
 			uri = g_file_get_uri (file);
 
-			g_string_append_printf (queries,
-			                        "DELETE FROM <%s> { "
-			                        "  <%s> tracker:mountPoint ?u "
-			                        "} WHERE { "
-			                        "  ?u a nfo:FileDataObject; "
-			                        "     nie:url \"%s\" "
-			                        "} ",
-			                        removable_device_urn, removable_device_urn, uri);
-
 			g_string_append_printf (queries,
 			                        "DROP GRAPH <%s> "
 			                        "INSERT INTO <%s> { "
@@ -607,7 +560,7 @@ set_up_mount_point (TrackerMinerFiles *miner,
 			                        "  ?u a nfo:FileDataObject; "
 			                        "     nie:url \"%s\" "
 			                        "}",
-			                        removable_device_urn, removable_device_urn, removable_device_urn, uri);
+						removable_device_urn, removable_device_urn, removable_device_urn, uri);
 
 			g_object_unref (file);
 			g_free (uri);
@@ -627,9 +580,6 @@ set_up_mount_point (TrackerMinerFiles *miner,
 	} else {
 		gchar *now;
 
-		g_debug ("Mount point state (UNMOUNTED) being set in DB for URN '%s'",
-		         removable_device_urn);
-
 		now = tracker_date_to_string (time (NULL));
 
 		g_string_append_printf (queries,
@@ -716,49 +666,27 @@ query_mount_points_cb (GObject      *source,
 	                                 (GDestroyNotify) g_free,
 	                                 NULL);
 
-	/* Make sure the root partition is always set to mounted, as GIO won't
-	 * report it as a proper mount */
-	g_hash_table_insert (volumes,
-	                     g_strdup (TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN),
-	                     GINT_TO_POINTER (VOLUME_MOUNTED));
-
-	/* Get mounted status from store */
 	for (i = 0; i < query_results->len; i++) {
 		gchar **row;
-
-		row = g_ptr_array_index (query_results, i);
-
-		if (strcmp (row[0], TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN) == 0) {
-			/* Update root partition to set also mounted in store */
-			g_hash_table_replace (volumes,
-			                     g_strdup (TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN),
-			                     GINT_TO_POINTER (VOLUME_MOUNTED | VOLUME_MOUNTED_IN_STORE));
-		} else {
-			/* Set status of known volumes in store */
-			g_hash_table_insert (volumes,
-			                     g_strdup (row[0]),
-			                     GINT_TO_POINTER (VOLUME_MOUNTED_IN_STORE));
-		}
-	}
-
-	/* Then, get all currently mounted non-REMOVABLE volumes, according to GIO */
-	uuids = tracker_storage_get_device_uuids (priv->storage, 0, TRUE);
-	for (u = uuids; u; u = u->next) {
-		const gchar *uuid;
-		gchar *non_removable_device_urn;
 		gint state;
 
-		uuid = u->data;
-		non_removable_device_urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
+		row = g_ptr_array_index (query_results, i);
+		state = VOLUME_MOUNTED_IN_STORE;
 
-		state = GPOINTER_TO_INT (g_hash_table_lookup (volumes, non_removable_device_urn));
-		state |= VOLUME_MOUNTED;
+		if (strcmp (row[0], TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN) == 0) {
+			/* Report non-removable media to be mounted by HAL as well */
+			state |= VOLUME_MOUNTED;
+		}
 
-		g_hash_table_replace (volumes, non_removable_device_urn, GINT_TO_POINTER (state));
+		g_hash_table_insert (volumes, g_strdup (row[0]), GINT_TO_POINTER (state));
 	}
 
-	/* Then, get all currently mounted REMOVABLE volumes, according to GIO */
+	g_hash_table_replace (volumes, g_strdup (TRACKER_NON_REMOVABLE_MEDIA_DATASOURCE_URN),
+	                      GINT_TO_POINTER (VOLUME_MOUNTED));
+
 	uuids = tracker_storage_get_device_uuids (priv->storage, TRACKER_STORAGE_REMOVABLE, FALSE);
+
+	/* Then, get all currently mounted volumes, according to GIO */
 	for (u = uuids; u; u = u->next) {
 		const gchar *uuid;
 		gchar *removable_device_urn;
@@ -797,33 +725,18 @@ query_mount_points_cb (GObject      *source,
 
 			if (urn) {
 				if (mount_point) {
-					g_debug ("Mount point state incorrect in DB for URN '%s', "
-						 "currently it is mounted on '%s'",
-					         urn,
-						 mount_point);
+					g_debug ("URN '%s' (mount point: %s) was not reported to be mounted, but now it is, updating state",
+					         urn, mount_point);
 				} else {
-					g_debug ("Mount point state incorrect in DB for URN '%s', "
-						 "currently it is mounted",
-					         urn);
+					g_debug ("URN '%s' was not reported to be mounted, but now it is, updating state", urn);
 				}
-
-				set_up_mount_point (TRACKER_MINER_FILES (miner),
-						    urn,
-						    mount_point,
-						    TRUE,
-						    accumulator);
+				set_up_mount_point (TRACKER_MINER_FILES (miner), urn, mount_point, TRUE, accumulator);
 			}
 		} else if (!(state & VOLUME_MOUNTED) &&
 		           (state & VOLUME_MOUNTED_IN_STORE)) {
 			if (urn) {
-				g_debug ("Mount pont state incorrect in DB for URN '%s', "
-					 "currently it is NOT mounted",
-					 urn);
-				set_up_mount_point (TRACKER_MINER_FILES (miner),
-						    urn,
-						    NULL,
-						    FALSE,
-						    accumulator);
+				g_debug ("URN '%s' was reported to be mounted, but it isn't anymore, updating state", urn);
+				set_up_mount_point (TRACKER_MINER_FILES (miner), urn, NULL, FALSE, accumulator);
 			}
 		}
 	}
@@ -861,22 +774,13 @@ mount_point_removed_cb (TrackerStorage *storage,
 {
 	TrackerMinerFiles *miner = user_data;
 	gchar *urn;
-	GFile *mount_point_file;
+
+	g_debug ("Removing mount point '%s'", mount_point);
 
 	urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
-	g_debug ("Mount point removed for URN '%s'", urn);
 
-	mount_point_file = g_file_new_for_path (mount_point);
-
-	/* Set mount point status in tracker-store */
 	set_up_mount_point (miner, urn, mount_point, FALSE, NULL);
-
-	/* Tell TrackerMinerFS to skip monitoring everything under the mount
-	 *  point (in case there was no pre-unmount notification) */
-	tracker_miner_fs_directory_remove (TRACKER_MINER_FS (miner), mount_point_file);
-
 	g_free (urn);
-	g_object_unref (mount_point_file);
 }
 
 static void
@@ -889,84 +793,33 @@ mount_point_added_cb (TrackerStorage *storage,
 {
 	TrackerMinerFiles *miner = user_data;
 	TrackerMinerFilesPrivate *priv;
+	GFile *file;
 	gchar *urn;
 	gboolean index_removable_devices;
 	gboolean index_optical_discs;
+	gboolean should_crawl;
 
 	priv = TRACKER_MINER_FILES_GET_PRIVATE (miner);
 
 	index_removable_devices = tracker_config_get_index_removable_devices (priv->config);
 	index_optical_discs = tracker_config_get_index_optical_discs (priv->config);
 
-	urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
-	g_message ("Mount point added for URN '%s'", urn);
+	g_message ("Added mount point '%s'", mount_point);
 
-	if (removable && !index_removable_devices) {
+	should_crawl = TRUE;	
+
+	if (removable && !tracker_config_get_index_removable_devices (priv->config)) {
 		g_message ("  Not crawling, removable devices disabled in config");
-	} else if (optical && !index_optical_discs) {
+		should_crawl = FALSE;
+	}
+
+	if (optical && !tracker_config_get_index_optical_discs (priv->config)) {
 		g_message ("  Not crawling, optical devices discs disabled in config");
-	} else if (!removable && !optical) {
-		GFile *mount_point_file;
-		GSList *l;
+		should_crawl = FALSE;
+	}
 
-		mount_point_file = g_file_new_for_path (mount_point);
-
-		/* Check if one of the recursively indexed locations is in
-		 *   the mounted path, or if the mounted path is inside
-		 *   a recursively indexed directory... */
-		for (l = tracker_config_get_index_recursive_directories (miner->private->config);
-		     l;
-		     l = g_slist_next (l)) {
-			GFile *config_file;
-
-			config_file = g_file_new_for_path (l->data);
-
-			if (g_file_equal (config_file, mount_point_file) ||
-			    g_file_has_prefix (config_file, mount_point_file)) {
-				/* If the config path is contained inside the mount path,
-				 *  then add the config path to re-check */
-				g_message ("  Re-check of configured path '%s' needed (recursively)",
-				           (gchar *) l->data);
-				tracker_miner_fs_directory_add (TRACKER_MINER_FS (user_data),
-				                                config_file,
-				                                TRUE);
-			} else if (g_file_has_prefix (mount_point_file, config_file)) {
-				/* If the mount path is contained inside the config path,
-				 *  then add the mount path to re-check */
-				g_message ("  Re-check of path '%s' needed (inside configured path '%s')",
-				           mount_point,
-				           (gchar *) l->data);
-				tracker_miner_fs_directory_add (TRACKER_MINER_FS (user_data),
-				                                mount_point_file,
-				                                TRUE);
-			}
-			g_object_unref (config_file);
-		}
-
-		/* Check if one of the non-recursively indexed locations is in
-		 *  the mount path... */
-		for (l = tracker_config_get_index_single_directories (miner->private->config);
-		     l;
-		     l = g_slist_next (l)) {
-			GFile *config_file;
-
-			config_file = g_file_new_for_path (l->data);
-			if (g_file_equal (config_file, mount_point_file) ||
-			    g_file_has_prefix (config_file, mount_point_file)) {
-				g_message ("  Re-check of configured path '%s' needed (non-recursively)",
-				           (gchar *) l->data);
-				tracker_miner_fs_directory_add (TRACKER_MINER_FS (user_data),
-				                                config_file,
-				                                FALSE);
-			}
-			g_object_unref (config_file);
-		}
-
-		g_object_unref (mount_point_file);
-	} else {
-		GFile *file;
-
-		g_message ("  Adding directories in removable/optical media to crawler's queue");
+	if (should_crawl) {
+		g_message ("  Adding directory to crawler's queue");
 
 		file = g_file_new_for_path (mount_point);
 		g_object_set_qdata_full (G_OBJECT (file),
@@ -984,6 +837,7 @@ mount_point_added_cb (TrackerStorage *storage,
 		g_object_unref (file);
 	}
 
+	urn = g_strdup_printf (TRACKER_DATASOURCE_URN_PREFIX "%s", uuid);
 	set_up_mount_point (miner, urn, mount_point, TRUE, NULL);
 	g_free (urn);
 }
@@ -1024,28 +878,14 @@ check_battery_status (TrackerMinerFiles *mf)
 		g_message ("Running on AC power");
 		should_pause = FALSE;
 		should_throttle = FALSE;
-	} else if (on_low_battery) {
-		g_message ("Running on LOW Battery, pausing");
-		should_pause = TRUE;
-		should_throttle = TRUE;
 	} else {
+		g_message ("Running on battery");
+
 		should_throttle = TRUE;
 
-		/* Check if miner should be paused based on configuration */
-		if (!tracker_config_get_index_on_battery (mf->private->config)) {
-			if (!tracker_config_get_index_on_battery_first_time (mf->private->config)) {
-				g_message ("Running on battery, but not enabled, pausing");
-				should_pause = TRUE;
-			} else if (tracker_db_manager_get_first_index_done()) {
-				g_message ("Running on battery and first-time index "
-				           "already done, pausing");
-				should_pause = TRUE;
-			} else {
-				g_message ("Running on battery, but first-time index not "
-				           "already finished, keeping on");
-			}
-		} else {
-			g_message ("Running on battery");
+		if (on_low_battery) {
+			g_message ("  Battery is LOW, pausing");
+			should_pause = TRUE;
 		}
 	}
 
@@ -1070,7 +910,6 @@ check_battery_status (TrackerMinerFiles *mf)
 	set_up_throttle (mf, should_throttle);
 }
 
-/* Called when battery status change is detected */
 static void
 battery_status_cb (GObject    *object,
                    GParamSpec *pspec,
@@ -1081,62 +920,18 @@ battery_status_cb (GObject    *object,
 	check_battery_status (mf);
 }
 
-/* Called when battery-related configuration change is detected */
-static void
-index_on_battery_cb (GObject    *object,
-                     GParamSpec *pspec,
-                     gpointer    user_data)
-{
-	TrackerMinerFiles *mf = user_data;
-
-	check_battery_status (mf);
-}
-
 #endif /* defined(HAVE_DEVKIT_POWER) || defined(HAVE_HAL) */
 
-/* Called when mining has finished the first time */
-static void
-miner_finished_cb (TrackerMinerFS *fs,
-                   gdouble         seconds_elapsed,
-                   guint           total_directories_found,
-                   guint           total_directories_ignored,
-                   guint           total_files_found,
-                   guint           total_files_ignored,
-                   gpointer        user_data)
-{
-	TrackerMinerFiles *mf = TRACKER_MINER_FILES (fs);
-
-	/* Create stamp file if not already there */
-	if (!tracker_db_manager_get_first_index_done ()) {
-		tracker_db_manager_set_first_index_done (TRUE);
-	}
-
-	/* And remove the signal handler so that it's not
-	 *  called again */
-	if (mf->private->finished_handler) {
-		g_signal_handler_disconnect (fs, mf->private->finished_handler);
-		mf->private->finished_handler = 0;
-	}
-
-#if defined(HAVE_DEVKIT_POWER) || defined(HAVE_HAL)
-	check_battery_status (mf);
-#endif /* defined(HAVE_DEVKIT_POWER) || defined(HAVE_HAL) */
-}
-
 static void
 mount_pre_unmount_cb (GVolumeMonitor    *volume_monitor,
                       GMount            *mount,
                       TrackerMinerFiles *mf)
 {
 	GFile *mount_root;
-	gchar *uri;
 
 	mount_root = g_mount_get_root (mount);
-	uri = g_file_get_uri (mount_root);
-	g_message ("Pre-unmount requested for '%s'", uri);
 	tracker_miner_fs_directory_remove (TRACKER_MINER_FS (mf), mount_root);
 	g_object_unref (mount_root);
-	g_free (uri);
 }
 
 static gboolean
@@ -1369,9 +1164,9 @@ miner_files_force_recheck_idle (gpointer user_data)
 }
 
 static void
-trigger_recheck_cb (GObject    *gobject,
-                    GParamSpec *arg1,
-                    gpointer    user_data)
+ignore_directories_cb (GObject    *gobject,
+                       GParamSpec *arg1,
+                       gpointer    user_data)
 {
 	TrackerMinerFiles *miner_files = user_data;
 
@@ -1558,16 +1353,6 @@ extractor_create_proxy (void)
 
 	if (!proxy) {
 		g_critical ("Could not create a DBusGProxy to the extract service");
-	} else {
-		/* Set default timeout for DBus requests to be around 60s.
-		 * Assuming that the files which need more time to get extracted are PDFs
-		 * using libpoppler, we already have a limit in the PDF extractor not to
-		 * spend more than 5s extraction contents. And, assuming the default
-		 * value of 10 in process-pool-limit, it means we may end up queueing up
-		 * to 10 PDF files which may need 5s each, so in order not to have dbus
-		 * timeouts in this case, any value greater than 5*10 would be good.
-		 */
-		dbus_g_proxy_set_default_timeout (proxy, EXTRACTOR_DBUS_TIMEOUT);
 	}
 
 	return proxy;
@@ -1580,9 +1365,12 @@ extractor_get_embedded_metadata_cb (DBusGProxy *proxy,
                                     GError     *error,
                                     gpointer    user_data)
 {
+	TrackerMinerFilesPrivate *priv;
 	ProcessFileData *data = user_data;
 	const gchar *uuid;
 
+	priv = TRACKER_MINER_FILES_GET_PRIVATE (data->miner);
+
 	if (error) {
 		/* Something bad happened, notify about the error */
 		tracker_miner_fs_file_notify (TRACKER_MINER_FS (data->miner), data->file, error);
@@ -1645,7 +1433,7 @@ extractor_get_embedded_metadata_cb (DBusGProxy *proxy,
 		                        "} WHERE { "
 		                        "  ?u a nfo:FileDataObject; "
 		                        "     nie:url \"%s\" "
-		                        "} ",
+		                        "}",
 		                        removable_device_urn, removable_device_urn, uri);
 
 		tracker_sparql_builder_append (data->sparql, queries->str);
@@ -1698,6 +1486,7 @@ process_file_cb (GObject      *object,
                  GAsyncResult *result,
                  gpointer      user_data)
 {
+	TrackerMinerFilesPrivate *priv;
 	TrackerSparqlBuilder *sparql;
 	ProcessFileData *data;
 	const gchar *mime_type, *urn, *parent_urn;
@@ -1711,6 +1500,7 @@ process_file_cb (GObject      *object,
 	data = user_data;
 	file = G_FILE (object);
 	sparql = data->sparql;
+	priv = TRACKER_MINER_FILES_GET_PRIVATE (data->miner);
 	file_info = g_file_query_info_finish (file, result, &error);
 
 	if (error) {
